@@ -7,9 +7,27 @@ class VersionedTableBuilder(VersionedBuilder):
     def table_name(self):
         return self.option('table_name') % self.model.__tablename__
 
+    @property
+    def parent_columns(self):
+        """
+        Returns a list of parent table columns.
+        """
+        if self.option('inspect_column_order'):
+            inspector = sa.inspect(self.model.metadata.bind)
+            columns = inspector.get_columns(self.model.__table__.name)
+            ordered_columns = []
+            for column in columns:
+                ordered_columns.append(
+                    self.model.__table__.c[column['name']]
+                )
+            return ordered_columns
+        else:
+            return self.model.__table__.c.values()
+
     def build_reflected_columns(self):
         columns = []
-        for column in self.model.__table__.c:
+
+        for column in self.parent_columns:
             # Make a copy of the column so that it does not point to wrong
             # table.
             column_copy = column.copy()
@@ -20,15 +38,6 @@ class VersionedTableBuilder(VersionedBuilder):
             columns.append(column_copy)
         return columns
 
-    def build_transaction_table_foreign_key(self):
-        return sa.schema.ForeignKeyConstraint(
-            [self.option('version_column_name')],
-            ['transaction_log.id'],
-            ondelete='CASCADE',
-            deferrable=True,
-            initially='DEFERRED'
-        )
-
     def build_version_column(self):
         return sa.Column(
             self.option('version_column_name'),
@@ -42,9 +51,6 @@ class VersionedTableBuilder(VersionedBuilder):
             items.extend(self.build_reflected_columns())
             items.append(self.build_version_column())
 
-        if extends is None:
-            items.append(self.build_transaction_table_foreign_key())
-
         return sa.schema.Table(
             extends.name if extends is not None else self.table_name,
             self.model.__bases__[0].metadata,
